__title__ = 'pycimvp'
__description__ = 'A Python library project for TDD + CI.'
__url__ = 'https://pycimvp.readthedocs.io/'
__version__ = '1.0.3'
# __build__ = 0x022501
__author__ = 'Lee Shiueh'
__author_email__ = 'lee.shiueh@gmail.com'
__license__ = 'Apache 2.0'
# __copyright__ = 'Copyright 2021'



"""Demo Module

A demo module example.

"""
from .__version__ import __title__
from .__version__ import __description__
from .__version__ import __url__
from .__version__ import __version__
from .__version__ import __author__
from .__version__ import __author_email__
from .__version__ import __license__


def read_module_meta() -> dict:
    """A simple function for test coverage coveralls.io integration."""

    # print(f'__title__ {__title__}')
    # print(f'__description__ {__description__}')
    # print(f'__url__ {__url__}')
    # print(f'__version__ {__version__}')
    # print(f'__author_email__ {__author_email__}')
    # print(f'__author__ {__author__}')
    # print(f'__license__ {__license__}')
    return {
        '__title__': __title__,
        '__description__': __description__,
        '__url__': __url__,
        '__version__': __version__,
        '__author_email__': __author_email__,
        '__author__': __author__,
        '__license__': __license__,
    }



import setuptools
import re

about = {}
with open('pycimvp/__version__.py') as fh:
    for line in fh.readlines():
        about.update(dict(re.findall('__([a-z]+)__ *= *\'([^"]+)\'', line)))

with open('README.rst', 'r') as f:
    readme = f.read()

setuptools.setup(
    name=about.get('title'),
    version=about.get('version'),
    description=about.get('description'),
    long_description=readme,
    long_description_content_type='text/x-rst',
    author=about.get('author'),
    author_email=about.get('author_email'),
    url=about.get('url'),
    license=about.get('license'),
    packages=['pycimvp'],
    # install_requires=['requests'],
    classifier=[
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy'
    ]
)
